@@ -19,21 +19,21 @@ options(oldcon)
 
 catalystm.mca <-
 if.R(r=glht(catalystm1.aov, linfct = mcp(catalyst = "Tukey")),
-     s=multicomp(catalystm1.aov, plot=F))
+     s=multicomp(catalystm1.aov, plot=FALSE))
 
 catalystm.lmat <- cbind("AB-D" =c(0, 1, 1, 0,-2),
                         "A-B"  =c(0, 1,-1, 0, 0),
                         "ABD-C"=c(0, 1, 1,-3, 1))
-if.R(r=catalystm.lmat <- catalystm.lmat[-2,],
+if.R(r=catalystm.lmat.glht <- catalystm.lmat[-2,],
      s={})
-dimnames(catalystm.lmat)[[1]] <-
-if.R(s=dimnames(catalystm.mca$lmat)[[1]],
-     r=dimnames(catalystm.mca$linfct)[[2]])
+
+if.R(s=dimnames(catalystm.lmat)[[1]] <-dimnames(catalystm.mca$lmat)[[1]],
+     r=dimnames(catalystm.lmat.glht)[[1]] <-dimnames(catalystm.mca$linfct)[[2]])
 
 
 catalystm.mmc <-
 if.R(r=glht.mmc(catalystm1.aov, linfct = mcp(catalyst = "Tukey"),
-                lmat=catalystm.lmat)
+                lmat=catalystm.lmat.glht, focus.lmat=catalystm.lmat[-1,])
     ,s=multicomp.mmc(catalystm1.aov, lmat=catalystm.lmat,
                      plot=FALSE)
 )
@@ -73,7 +73,7 @@ par(old.mar)
 
 
 ## illustrate the construction of the isomeans grid and the contrasts
-source(hh("scripts/MMC.mmc.explain.R"))  ## mmc.jcs.explain() and tpg.col()
+source(hh("demo/MMC.mmc.explain.R"))  ## mmc.jcs.explain() and tpg.col()
 
 group <- levels(catalystm$catalyst)
 n <- c(4,4,4,4)
